@@ -375,7 +375,7 @@ def plot4(kk, kk_MD, frequencies, frequencies_disp, x_labels, DOS_info):
 
     for j in range(0,n_branches):
         # graph_MD = ax.scatter(kk_MD, frequencies_MD[0,j,:], color='blue', label='MD frequencies')
-        graph_ft = ax.scatter(kk_MD, frequencies[0,j,:], color='red', label='finite T dispersion', linewidth=1)
+        graph_ft, = ax.plot(kk, frequencies[0,j,:], color='red', label='finite T dispersion', linewidth=1)
         graph_disp, = ax.plot(kk, frequencies_disp[0,j,:], color='black', label='0K dispersion', linewidth=1)
 #        f_gamma = interpolate.interp1d(kk, frequencies[1,j,:], kind=1)
 #        y1, y2 = f(x)+f_gamma(x)/2, f(x)-f_gamma(x)/2
